==> ra-sdk-0.0.1-20191224.022434-2-sources.jar: com/xdja/ra/bean/PersonUser.java <==
package com.xdja.ra.bean;


/**
 * @author: ggp
 * @Date: 2019/10/17 21:41
 * @Description:
 */
public class PersonUser {
    /**
     * 非必须	联系地址
     */
    private String address;
    /**
     * 非必须	单位地址
     */
    private String companyAddress;
    /**
     * 非必须	单位名称
     */
    private String companyName;
    /**
     * 非必须	邮箱地址
     */
    private String email;
    /**
     * 必须	证件号码
     */
    private String licenseNumber;
    /**
     * 必须	证件类型 1:身份证 2:军官证 3:护照 4:其它
     */
    private Integer licenseType;
    /**
     * 必须	用户姓名
     */
    private String personName;
    /**
     * 非必须	邮政编码
     */
    private String postalCode;
    /**
     * 非必须	备注信息
     */
    private String remark;
    /**
     * 非必须	联系电话
     */
    private Integer sex;
    /**
     * 非必须  联系电话
     */
    private String telNumber;

    /**
     * 用户状态  0 正常  1 停用
     */
    private int status;

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getCompanyAddress() {
        return companyAddress;
    }

    public void setCompanyAddress(String companyAddress) {
        this.companyAddress = companyAddress;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getLicenseNumber() {
        return licenseNumber;
    }

    public void setLicenseNumber(String licenseNumber) {
        this.licenseNumber = licenseNumber;
    }

    public Integer getLicenseType() {
        return licenseType;
    }

    public void setLicenseType(Integer licenseType) {
        this.licenseType = licenseType;
    }

    public String getPersonName() {
        return personName;
    }

    public void setPersonName(String personName) {
        this.personName = personName;
    }

    public String getPostalCode() {
        return postalCode;
    }

    public void setPostalCode(String postalCode) {
        this.postalCode = postalCode;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }

    public String getTelNumber() {
        return telNumber;
    }

    public void setTelNumber(String telNumber) {
        this.telNumber = telNumber;
    }

    public int getStatus() {
        return status;
    }

    public void setStatus(int status) {
        this.status = status;
    }

    @Override
    public String toString() {
        return "PersonUser{" +
                "address='" + address + '\'' +
                ", companyAddress='" + companyAddress + '\'' +
                ", companyName='" + companyName + '\'' +
                ", email='" + email + '\'' +
                ", licenseNumber='" + licenseNumber + '\'' +
                ", licenseType=" + licenseType +
                ", personName='" + personName + '\'' +
                ", postalCode='" + postalCode + '\'' +
                ", remark='" + remark + '\'' +
                ", sex=" + sex +
                ", telNumber='" + telNumber + '\'' +
                ", status=" + status +
                '}';
    }
}

==> ra-sdk-2.0.0-sources.jar: com/xdja/ra/bean/PersonUser.java <==
package com.xdja.ra.bean;


/**
 * @author: ggp
 * @Date: 2019/10/17 21:41
 * @Description:
 */
public class PersonUser {
    /**
     * 非必须	联系地址
     */
    private String address;
    /**
     * 非必须	单位地址
     */
    private String companyAddress;
    /**
     * 非必须	单位名称
     */
    private String companyName;
    /**
     * 非必须	邮箱地址
     */
    private String email;
    /**
     * 必须	证件号码
     */
    private String licenseNumber;
    /**
     * 必须	证件类型 1:身份证 2:军官证 3:护照 4:其它
     */
    private Integer licenseType;
    /**
     * 必须	用户姓名
     */
    private String personName;
    /**
     * 非必须	邮政编码
     */
    private String postalCode;
    /**
     * 非必须	备注信息
     */
    private String remark;
    /**
     * 必须	性别  0-男  1-女
     */
    private Integer sex;
    /**
     * 非必须  联系电话
     */
    private String telNumber;

    /**
     * 非必须  用户状态  0 正常  1 停用
     */
    private int status;

    public PersonUser() {
    }

    /**
     * 必填项入参构造函数
     *
     * @param licenseNumber
     * @param licenseType
     * @param personName
     */
    public PersonUser(String licenseNumber, Integer licenseType, String personName) {
        this.licenseNumber = licenseNumber;
        this.licenseType = licenseType;
        this.personName = personName;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getCompanyAddress() {
        return companyAddress;
    }

    public void setCompanyAddress(String companyAddress) {
        this.companyAddress = companyAddress;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getLicenseNumber() {
        return licenseNumber;
    }

    public void setLicenseNumber(String licenseNumber) {
        this.licenseNumber = licenseNumber;
    }

    public Integer getLicenseType() {
        return licenseType;
    }

    public void setLicenseType(Integer licenseType) {
        this.licenseType = licenseType;
    }

    public String getPersonName() {
        return personName;
    }

    public void setPersonName(String personName) {
        this.personName = personName;
    }

    public String getPostalCode() {
        return postalCode;
    }

    public void setPostalCode(String postalCode) {
        this.postalCode = postalCode;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }

    public String getTelNumber() {
        return telNumber;
    }

    public void setTelNumber(String telNumber) {
        this.telNumber = telNumber;
    }

    public int getStatus() {
        return status;
    }

    public void setStatus(int status) {
        this.status = status;
    }

    @Override
    public String toString() {
        return "PersonUser{" +
                "address='" + address + '\'' +
                ", companyAddress='" + companyAddress + '\'' +
                ", companyName='" + companyName + '\'' +
                ", email='" + email + '\'' +
                ", licenseNumber='" + licenseNumber + '\'' +
                ", licenseType=" + licenseType +
                ", personName='" + personName + '\'' +
                ", postalCode='" + postalCode + '\'' +
                ", remark='" + remark + '\'' +
                ", sex=" + sex +
                ", telNumber='" + telNumber + '\'' +
                ", status=" + status +
                '}';
    }
}
